%global __strip %{_mingw32_strip}
%global __objdump %{_mingw32_objdump}
%global _use_internal_dependency_generator 0
%global __find_requires %{_mingw32_findrequires}
%global __find_provides %{_mingw32_findprovides}
%define __debug_install_post %{_mingw32_debug_install_post}

## NOTE: Lots of files in various subdirectories have the same name (such as
## "LICENSE") so this short macro allows us to distinguish them by using their
## directory names (from the source tree) as prefixes for the files.
%global add_to_doc_files() \
    mkdir -p %{buildroot}%{_docdir}/%{name}-%{version} ||: ; \
    cp -p %1  %{buildroot}%{_docdir}/%{name}-%{version}/$(echo '%1' | sed -e 's!/!.!g')

#define	svn_revision	41071

## Optional build modifications...
## --with 3dtransforms: Enables support for 3-D transforms.
##	(Default: No)
##
## --with coverage: Enables compile-time checking of code coverage.
##	(Default: No)
##
## --with debug: Enable more verbose debugging. Makes runtime a bit slower.
##	Also disables the optimized memory allocator.
##	(Default: No)
##
## --with html5video: Enable HTML5 video element support using Gstreamer.
##	(Default: No) 
##
## --with jit: Enable JIT ("just-in-time") JavaScript compiling support.
##	Only supported on ix86 at this time, according to upstream.
##	(Default: No)
##	
## --with svg: Experimental SVG support (filters)
##	(Default: No) 
##
## --with wml: Build support for WML
##	(Default: No)

%bcond_with	3dtransforms
%bcond_with	coverage
%bcond_with	debug
%bcond_with	html5video
%bcond_with	jit
%bcond_with	svg
%bcond_with	wml

Name:		mingw32-webkitgtk
Version:	1.3.6
Release:	2%{?dist}
Summary:	MinGW Windows web content engine library

Group:		Development/Libraries
License:	LGPLv2+ and BSD
URL:		http://webkit.org/

#Source0:	http://nightly.webkit.org/files/trunk/src/WebKit-r%{svn_revision}.tar.bz2
Source0:	http://www.webkitgtk.org/webkit-%{version}.tar.gz

# The Fedora MinGW libjpeg uses the datatype 'jpeg_boolean' instead
# of 'boolean' to avoid a conflict with the header rpcndr.h
Patch0:		webkit-jpeg-boolean-fix.patch

# Several changes required to get webkitgtk cross-compiled
# Originally created by Mikkel Kruse Johnsen
# https://bugs.webkit.org/show_bug.cgi?id=23872
Patch1:		webkit-mingw-fixes.patch

# The DumpRenderTree tool fails to compile for version 1.3.6
# As this tool isn't packaged a ugly hack can be applied to make it compile
Patch2:		webkit-dump-render-tree-compile-fix.patch

BuildArch:	noarch

BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	gperf

# Required for glib-mkenums
BuildRequires:	glib2-devel

BuildRequires:	gettext
BuildRequires:	mingw32-filesystem
BuildRequires:	mingw32-gcc
BuildRequires:	mingw32-gcc-c++
BuildRequires:	mingw32-binutils
BuildRequires:	mingw32-gtk2
BuildRequires:	mingw32-libxml2
BuildRequires:	mingw32-libsoup
BuildRequires:	mingw32-libidn
BuildRequires:	mingw32-sqlite
BuildRequires:	mingw32-libxslt
BuildRequires:	mingw32-pthreads
BuildRequires:	mingw32-enchant

## Conditional dependencies...
%if %{with html5video}
BuildRequires:	mingw32-gstreamer
%endif


%description 
WebKitGTK+ is an open-source Web content engine library.
This package contains the shared libraries for the WebKit GTK+ port
as well as the sample GtkLauncher tool. 

This is the MinGW port of WebKitGTK+


%package static
Summary:	Static version of the MinGW Windows WebKitGTK+ library
Requires:	%{name} = %{version}-%{release}
Group:		Development/Libraries

%description static
Static version of the MinGW Windows WebKitGTK+ library.


%{?_mingw32_debug_package}


%prep
%setup -qn "webkit-%{version}"

%patch0 -p0 -b .jpeg_boolean
%patch1 -p0 -b .mingw
%patch2 -p0 -b .dumprendertree


%build
%{_mingw32_configure}						\
			--with-target=win32			\
			--with-font-backend=pango		\
			--with-unicode-backend=glib		\
			--disable-video				\
			--enable-static --enable-shared		\
%{?with_3dtransforms:	--enable-3D-transforms		}	\
%{?with_coverage:	--enable-coverage		}	\
%{?with_debug:		--enable-debug			}	\
%{?with_html5video:	--enable-video			}	\
%{?with_jit:		--enable-jit			}	\
%{?with_svg:		--enable-svg-filters		}	\
%{?with_wml:		--enable-wml			}
	
make %{?_smp_mflags} V=99


%install
make install DESTDIR=%{buildroot}
install -m 755 Programs/.libs/GtkLauncher.exe %{buildroot}%{_mingw32_bindir}

%find_lang webkit-2.0


## Copy over and rename the various files for %%doc inclusion.
%add_to_doc_files JavaScriptCore/icu/LICENSE
%add_to_doc_files WebKit/LICENSE
%add_to_doc_files WebCore/icu/LICENSE
%add_to_doc_files WebCore/LICENSE-APPLE
%add_to_doc_files WebCore/LICENSE-LGPL-2
%add_to_doc_files WebCore/LICENSE-LGPL-2.1

%add_to_doc_files JavaScriptCore/pcre/COPYING
%add_to_doc_files JavaScriptCore/COPYING.LIB

%add_to_doc_files JavaScriptCore/icu/README
%add_to_doc_files WebKit/gtk/po/README

%add_to_doc_files JavaScriptCore/AUTHORS
%add_to_doc_files JavaScriptCore/pcre/AUTHORS

%add_to_doc_files JavaScriptCore/THANKS

%add_to_doc_files WebKit/gtk/NEWS


%files -f webkit-2.0.lang
%defattr(-,root,root,-)
%{_docdir}/%{name}-%{version}/
%{_mingw32_bindir}/jsc-1.exe
%{_mingw32_bindir}/GtkLauncher.exe
%{_mingw32_bindir}/libwebkitgtk-1.0-0.dll
%{_mingw32_includedir}/webkit-1.0/
%{_mingw32_libdir}/libwebkitgtk-1.0.dll.a
%{_mingw32_libdir}/libwebkitgtk-1.0.la
%{_mingw32_libdir}/pkgconfig/webkit-1.0.pc
%{_mingw32_datadir}/glib-2.0/schemas/org.webkitgtk-1.0.gschema.xml
%{_mingw32_datadir}/webkit-1.0/
%{_mingw32_datadir}/webkitgtk-1.0/

%files static
%defattr(-,root,root,-)
%{_mingw32_libdir}/libwebkitgtk-1.0.a


%changelog
* Tue Nov 16 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 1.3.6-2
- Improved the description
- Bundle the various license files
- Dropped the BuildRoot tag, the %%clean section and the
  'rm -rf %{buildroot}' from the %%install section as they
  aren't needed anymore these days

* Sun Nov 14 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 1.3.6-1
- Update to 1.3.6

* Sun Nov  7 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 1.2.5-1
- Update to 1.2.5
- Automatically generate debuginfo subpackage
- Use %%global instead of %%define
- Dropped the manual strip command
- Dropped old patches

* Fri May 22 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 1.1.7-1
- Update to 1.1.7

* Sun May 10 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 1.1.6-1
- Update to 1.1.6
- Updated the patches to apply cleanly against version 1.1.6
- Renamed the package to mingw32-webkitgtk
- Merged the changes from the native webkitgtk package up to 1.1.6-1
- Added a BR: mingw32-enchant (required as of version 1.1.6)

* Sat Apr 25 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 1.1.5-1
- Adjusted native WebKit .spec file so that it supports mingw32
- Update to 1.1.5
- Updated Source URL
- Added patches from Mikkel Kruse Johnsen for compilation on Win32 environments

* Sat Mar 07 2009 Peter Gordon <peter@thecodergeek.com> - 1.1.1-1
- Update to new upstream release (1.1.1), includes a soname bump.
- Enable gnome-keyring support.

* Wed Mar  4 2009 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> - 1.1.0-0.21.svn41071
- Compile libJavaScriptCore.a with -fno-strict-aliasing to
  do workaround for #488112

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.0-0.20.svn41071
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Feb 20 2009 Peter Gordon <peter@thecodergeek.com> 1.1.0-0.19.svn41071
- Update to new upstream snapshot (SVN 41071).
- Drop libsoup build conditional. Use libsoup as default HTTP backend instead
  of cURL, following upstream's default.

* Fri Jan 30 2009 Peter Gordon <peter@thecodergeek.com> 1.1.0-0.18.svn40351
- Fix ownership of doc directory...this time without the oops (#473619).
- Bump package version number to match that used in the configure/build
  scripts. (Thanks to Martin Sourada for the bug report via email.)

* Thu Jan 29 2009 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.17.svn40351
- Update to new upstream snapshot (SVN 40351): adds the WebPolicyDelegate
  implementaton and related API (#482739).
- Drop Bison 2.4 patch (fixed upstream):
  - bison24.patch
- Fixes CVE-2008-6059: Sensitive information disclosure from cookies via
  XMLHttpRequest calls (#484197).

* Sat Nov 29 2008 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.16.svn39370
- Update to new upstream snapshot (SVN 39370)
- Fix ownership of %%_docdir in the doc subpackage. 
- Resolves: bug 473619 (WebKit : Unowned directories).
- Adds webinspector data to the gtk-devel subpackage.
- Add patch from upstream bug 22205 to fix compilation errors with Bison 2.4:
  + bison24.patch
- Add build-time conditional for WML support.

* Thu Oct 23 2008 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.15.svn37790
- Update to new upstream snapshot (SVN 37790).
- Default to freetype font backend for improved CJK/Unicode support. (#448693)
- Add some notes to the build options comments block.
- Add a build-time conditional for jit

* Sun Aug 24 2008 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.14.svn35904
- Update to new upstream snapshot (SVN 35904)

* Fri Jul 04 2008 Peter Gordon <peter@thecodergeek.com>
- Remove outdated and unnecessary GCC 4.3 patch:
  - gcc43.patch
- Fix the curl-devel BuildRequire conditional. (It is only needed when building
  against curl instead of libsoup.)

* Thu Jun 12 2008 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.13.svn34655
- Update to new upstream snapshot (SVN 34655)
- Add some build-time conditionals for non-default features: debug, 
  html5video, libsoup, pango, svg. 

* Tue Jun  3 2008 Caolán McNamara <caolanm@redhat.com> - 1.0.0-0.12.svn34279
- rebuild for new icu

* Tue Jun  3 2008 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> - 1.0.0-0.11.svn34279
- Update to new upstream snapshot (SVN 34279) anyway
- Add BR: libXt-devel

* Tue Apr 29 2008 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.10.svn32531
- Remove the -Qt subpackage stuff. QtWebKit is now included in Qt proper, as
  of qt-4.4.0-0.6.rc1. (We no longer need separate build-qt and build-gtk
  subdirectories either.)
- Reference: bug 442200 (RFE: WebKit Migration)
- Add libjpeg dependency (was previously pulled in by the qt4-devel dependency
  tree).

* Mon Apr 28 2008 Mamoru Tasaka <mtasaka@ioa.s.u-tokyo.ac.jp> - 1.0.0-0.9.svn32531
- Update to new upstream snapshot (SVN 32531).
- Fix bug 443048 and hopefully fix bug 444445
- Modify the process of building GTK+ port a bit
- on qt port WebKit/qt/Plugins is not built for qt >= 4.4.0

* Sat Apr 12 2008 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.8.svn31787
- Update to new upstream snapshot (SVN 31787).
- Resolves: CVE-2008-1010 (bug 438532: Arbitrary code execution) and
  CVE-2008-1011 (bug 438531: Cross-Site Scripting).
- Switch to using autotools for building the GTK+ port.

* Wed Mar 05 2008 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.7.svn30667
- Fix the WebKitGtk pkgconfig data (should depend on gtk+-2.0). Resolves
  bug 436073 (Requires: gtk+-2.0 missing from WebKitGtk.pc).
- Thanks to Mamoru Tasaka for helping find and squash these many bugs. 
  
* Sat Mar 01 2008 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.6.svn30667
- Fix include directory naming. Resolves: bug 435561 (Header file <> header
  file location mismatch)
- Remove qt4-devel runtime dependency and .prl file from WebKit-gtk-devel.
  Resolves: bug 433138 (WebKit-gtk-devel has a requirement on qt4-devel) 

* Fri Feb 29 2008 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.5.svn30667
- Update to new upstream snapshot (SVN 30667)
- Add some build fixes for GCC 4.3:
  + gcc43.patch

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.0.0-0.5.svn29336
- Autorebuild for GCC 4.3

* Wed Jan 09 2008 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.4.svn29336
- Update to new upstream snapshot (SVN 29336).
- Drop TCSpinLock pthread workaround (fixed upstream):
  - TCSpinLock-use-pthread-stubs.patch

* Thu Dec 06 2007 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.3.svn28482
- Add proper %%defattr line to qt, qt-devel, and doc subpackages.
- Add patch to forcibly build the TCSpinLock code using the pthread
  implementation:
  + TCSpinLock-use-pthread-stubs.patch

* Thu Dec 06 2007 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.2.svn28482
- Package renamed from WebKitGtk.
- Update to SVN 28482.
- Build both the GTK and Qt ports, putting each into their own respective
  subpackages.
- Invoke qmake-qt4 and make directly (with SMP build flags) instead of using
  the build-webkit script from upstream.
- Add various AUTHORS, README, and LICENSE files (via the doc subpackage). 

* Tue Dec 04 2007 Peter Gordon <peter@thecodergeek.com> 1.0.0-0.1.svn28383
- Initial packaging for Fedora.
